@@ -859,6 +859,7 @@ mod tests {
                 assert_eq!(format!("{}", ts.format("MONtH").unwrap()), "AUGUST");
                 assert_eq!(format!("{}", ts.format("Month").unwrap()), "August");
                 assert_eq!(format!("{}", ts.format("month").unwrap()), "august");
+                assert_eq!(format!("{}", ts.format("WW").unwrap()), "32");
                 assert_eq!(format!("{}", ts.format("W").unwrap()), "1");
                 assert_eq!(format!("{}", ts.format("DAY").unwrap()), "SUNDAY");
                 assert_eq!(format!("{}", ts.format("DAy").unwrap()), "SUNDAY");
@@ -896,6 +897,7 @@ mod tests {
                 let ts = generate_ts(1970, 1, 1, 7, 8, 9, 10);
                 assert_eq!(format!("{}", ts.format("day").unwrap()), "thursday");
                 assert_eq!(format!("{}", ts.format("d").unwrap()), "5");
+                assert_eq!(format!("{}", ts.format("ww").unwrap()), "01");
                 assert_eq!(format!("{}", ts.format("w").unwrap()), "1");
 
                 let ts = generate_ts(1970, 1, 2, 7, 8, 9, 10);
@@ -904,6 +906,7 @@ mod tests {
                 let ts = generate_ts(1969, 12, 31, 7, 8, 9, 10);
                 assert_eq!(format!("{}", ts.format("day").unwrap()), "wednesday");
                 assert_eq!(format!("{}", ts.format("d").unwrap()), "4");
+                assert_eq!(format!("{}", ts.format("ww").unwrap()), "53");
                 assert_eq!(format!("{}", ts.format("w").unwrap()), "5");
 
                 let ts = generate_ts(1969, 10, 1, 7, 8, 9, 10);
@@ -1050,9 +1053,15 @@ mod tests {
                 assert_eq!(
                     format!(
                         "{}",
-                        ts.format("DAY DaY DY D W MM MM yyyy YYYY MI MI").unwrap()
+                        ts.format("DAY DaY DY D W WW WW MM MM yyyy YYYY MI MI")
+                            .unwrap()
                     ),
-                    "SUNDAY Sunday SUN 1 4 04 04 2021 2021 04 04"
+                    "SUNDAY Sunday SUN 1 4 17 17 04 04 2021 2021 04 04"
+                );
+
+                assert_eq!(
+                    format!("{}", ts.format("DAYDaYDYDWWWWWDMMMMyyyyYYYYMIMI").unwrap()),
+                    "SUNDAYSundaySUN11717410404202120210404"
                 );
             }
 
